@@ -1,7 +1,5 @@
 package Dancer::Template::Mason2;
-BEGIN {
-  $Dancer::Template::Mason2::VERSION = '0.04';
-}
+$Dancer::Template::Mason2::VERSION = '0.05';
 use Dancer::Config 'setting';
 use File::Basename;
 use FindBin;
@@ -36,10 +34,21 @@ sub render {
     return $content;
 }
 
+sub view {
+    my ( $self, $view ) = @_;
+
+    my $views_dir = Dancer::App->current->setting('views');
+    my $tmpl_ext  = $self->config->{extension} || $self->default_tmpl_ext();
+    my $view_path = sprintf( '%s/%s.%s', $views_dir, $view, $self->default_tmpl_ext );
+    return $view_path;
+}
+
+sub view_exists { return 1; }
+
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -48,7 +57,7 @@ Dancer::Template::Mason2 - Mason 2.x wrapper for Dancer
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -116,4 +125,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
